@@ -5,7 +5,7 @@
 #
 ###############################################################################
 #
-#   $Id: Database.pm,v 1.3 2000/06/22 08:42:00 rjray Exp $
+#   $Id: Database.pm,v 1.8 2000/08/08 07:05:13 rjray Exp $
 #
 #   Description:    The RPM::Database class provides access to the RPM database
 #                   as a tied hash, whose keys are taken as the names of
@@ -13,11 +13,10 @@
 #                   objects.
 #
 #   Functions:      new
-#                   STORE
-#                   CLEAR
-#                   DELETE
+#                   import
 #
-#   Libraries:      RPM::Header
+#   Libraries:      RPM
+#                   RPM::Header
 #
 #   Global Consts:  None.
 #
@@ -30,14 +29,14 @@ package RPM::Database;
 require 5.005;
 
 use strict;
-use vars qw($VERSION $revision);
-use subs qw(new);
+use vars qw($VERSION $revision %RPM $RPM);
+use subs qw(new import);
 
 require RPM;
 require RPM::Header;
 
-$VERSION = $RPM::VERSION;
-$revision = do { my @r=(q$Revision: 1.3 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
+$VERSION = '0.27';
+$revision = do { my @r=(q$Revision: 1.8 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
 
 1;
 
@@ -50,6 +49,59 @@ sub new
     return (tied %hash);
 }
 
+###############################################################################
+#
+#   Sub Name:       import
+#
+#   Description:    This lies in wait to see if someone actually tries to
+#                   import from this package. If they do, check that it is
+#                   allowed and do it if it is.
+#
+#                   At present, only "%RPM" or "$RPM" is allowed. If that is
+#                   the requested export, then the hash is tied to the RPM
+#                   database (with no extra arguments) then exported to the
+#                   caller's namespace.
+#
+#   Arguments:      NAME      IN/OUT  TYPE      DESCRIPTION
+#                   $class    in      scalar    Name of this package
+#                   @args     in      list      Requested exports
+#
+#   Globals:        None.
+#
+#   Environment:    None.
+#
+#   Returns:        void context
+#
+###############################################################################
+sub import
+{
+    my ($class, @args) = @_;
+
+    my $callpkg = caller(0);
+
+    no strict 'refs';
+
+    for my $arg (@args)
+    {
+        if ($arg eq '%RPM' and ! (tied %RPM))
+        {
+            tie %RPM, "RPM::Database";
+            *{"${callpkg}::RPM"} = \%{"${class}::RPM"};
+        }
+        elsif ($arg eq '$RPM' and ! $RPM)
+        {
+            tie %RPM, "RPM::Database" unless (tied %RPM);
+            $RPM = (tied %RPM);
+            *{"${callpkg}::RPM"} = \${"${class}::RPM"};
+        }
+        else
+        {
+            warn "$class: Unknown export requested: $arg, ";
+            return;
+        }
+    }
+}
+
 __END__
 
 =head1 NAME
@@ -154,6 +206,25 @@ in fact more than one matching record, all are returned.
 
 =back
 
+=head2 Importable Defaults
+
+Given that there may be only one concurrent process with the rpm database
+open, and given that such would lead to a lot of program code starting with
+the same sequence of use/tie or use/new, the following identifiers may be
+imported from the package:
+
+=over
+
+=item %RPM
+
+A hash pre-tied to the RPM::Database package (and thus the rpm database).
+
+=item $RPM
+
+A RPM::Database object, referencing a hash tied to the rpm database.
+
+=back
+
 =head1 DIAGNOSTICS
 
 Direct binding to the internal error-management of B<rpm> is still under
